aboutsummaryrefslogtreecommitdiffstats
path: root/make/scripts/runtest.sh
diff options
context:
space:
mode:
Diffstat (limited to 'make/scripts/runtest.sh')
-rw-r--r--make/scripts/runtest.sh14
1 files changed, 10 insertions, 4 deletions
diff --git a/make/scripts/runtest.sh b/make/scripts/runtest.sh
index c58b69a..9484eb4 100644
--- a/make/scripts/runtest.sh
+++ b/make/scripts/runtest.sh
@@ -8,14 +8,20 @@ if [ -z "$builddir" ] ; then
exit 1
fi
+LOG=runtest.log
+rm -f $LOG
+
+#D_ARGS="-Djogamp.debug.ProcAddressHelper=true -Djogamp.debug.NativeLibrary=true"
+D_ARGS="-Djogamp.debug.TraceLock"
+
function onetest() {
clazz=$1
shift
echo $clazz
- java -Djava.library.path=$builddir/obj:$builddir/test/build/natives -classpath lib/junit.jar:$builddir/classes:$builddir/test/build/classes $clazz
+ java $D_ARGS -Djava.library.path=$builddir/obj:$builddir/test/build/natives -classpath lib/junit.jar:$builddir/classes:$builddir/test/build/classes $clazz
echo
}
-onetest com.jogamp.common.util.TestRecursiveToolkitLock
-#onetest com.jogamp.gluegen.test.TestPointerBufferEndian
-#onetest com.jogamp.gluegen.test.TestStructAccessorEndian
+onetest com.jogamp.common.util.TestRecursiveToolkitLock 2>&1 | tee -a $LOG
+#onetest com.jogamp.gluegen.test.TestPointerBufferEndian 2>&1 | tee -a $LOG
+#onetest com.jogamp.gluegen.test.TestStructAccessorEndian 2>&1 | tee -a $LOG